==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.18.jar: sources/QtJambi3DCore/QPropertyNodeAddedChange_shell.cpp <==
#include "QPropertyNodeAddedChange_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QPropertyNodeAddedChange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QPropertyNodeAddedChange")
    Qt3DCore::QPropertyNodeAddedChange *_ptr = reinterpret_cast<Qt3DCore::QPropertyNodeAddedChange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPropertyNodeAddedChange_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyNodeAddedChange_shell) ); }

jmethodID QPropertyNodeAddedChange_shell::__shell_javaMethod(int pos) const { return QPropertyNodeAddedChange_shell::__shell()->javaMethod(typeid(Qt3DCore::QPropertyNodeAddedChange), pos); }

// emitting (writeShellConstructor)
QPropertyNodeAddedChange_shell::QPropertyNodeAddedChange_shell(Qt3DCore::QNodeId subjectId0, Qt3DCore::QNode* node1)
    : Qt3DCore::QPropertyNodeAddedChange(subjectId0, node1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QPropertyNodeAddedChange::QPropertyNodeAddedChange_shell(Qt3DCore::QNodeId subjectId0, Qt3DCore::QNode* node1)", QPropertyNodeAddedChange_shell::__shell())
    QPropertyNodeAddedChange_shell::__shell()->constructed(typeid(Qt3DCore::QPropertyNodeAddedChange));
}

// emitting (writeShellDestructor)
QPropertyNodeAddedChange_shell::~QPropertyNodeAddedChange_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QPropertyNodeAddedChange::~Qt3DCore::QPropertyNodeAddedChange()", QPropertyNodeAddedChange_shell::__shell())
    QPropertyNodeAddedChange_shell::__shell()->destructed(typeid(Qt3DCore::QPropertyNodeAddedChange));
}

void QPropertyNodeAddedChange_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyNodeAddedChange_shell*>(ptr)->QPropertyNodeAddedChange_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QPropertyNodeAddedChange));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)
void __qt_construct_Qt3DCore_QPropertyNodeAddedChange_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    jobject node1 = __java_arguments[1].l;
    Qt3DCore::QNode* __qt_node1 = qtjambi_cast<Qt3DCore::QNode* >(__jni_env, node1);
    Qt3DCore::QPropertyNodeAddedChange *__qt_this = new(__qtjambi_ptr) QPropertyNodeAddedChange_shell(__qt_subjectId0, __qt_node1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPropertyNodeAddedChange_shell
void __qt_destruct_Qt3DCore_QPropertyNodeAddedChange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QPropertyNodeAddedChange")
    reinterpret_cast<QPropertyNodeAddedChange_shell*>(ptr)->~QPropertyNodeAddedChange_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QPropertyNodeAddedChange::QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyNodeAddedChange_initialize_1native__Lio_qt_qt3d_core_QPropertyNodeAddedChange_2Lio_qt_qt3d_core_QNodeId_2Lio_qt_qt3d_core_QNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0,
 jobject node1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QPropertyNodeAddedChange::QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = subjectId0;
        arguments[1].l = node1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QPropertyNodeAddedChange_0, sizeof(QPropertyNodeAddedChange_shell), typeid(Qt3DCore::QPropertyNodeAddedChange), true, &deleter_Qt3DCore_QPropertyNodeAddedChange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QPropertyNodeAddedChange::addedNodeId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyNodeAddedChange_addedNodeId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QPropertyNodeAddedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QPropertyNodeAddedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QPropertyNodeAddedChange::addedNodeId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->addedNodeId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QPropertyNodeAddedChange::metaObject()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyNodeAddedChange_metaObject_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QPropertyNodeAddedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QPropertyNodeAddedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QPropertyNodeAddedChange::metaObject()const", __qt_this)
        const QMetaObject* __qt_return_value = __qt_this->metaObject();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QPropertyNodeAddedChange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QPropertyNodeAddedChange>("Qt3DCore::QPropertyNodeAddedChange", "io/qt/qt3d/core/QPropertyNodeAddedChange");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QPropertyNodeAddedChange, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QPropertyNodeAddedChange_0, "Lio/qt/qt3d/core/QNodeId;Lio/qt/qt3d/core/QNode;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QPropertyNodeAddedChange);
    registerSizeOfShell(typeId, sizeof(QPropertyNodeAddedChange_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QStaticPropertyValueAddedChangeBase, Qt3DCore::QPropertyNodeAddedChange>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.20.jar: sources/QtJambi3DCore/QPropertyNodeAddedChange_shell.cpp <==
#include "QPropertyNodeAddedChange_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QPropertyNodeAddedChange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QPropertyNodeAddedChange")
    Qt3DCore::QPropertyNodeAddedChange *_ptr = reinterpret_cast<Qt3DCore::QPropertyNodeAddedChange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPropertyNodeAddedChange_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyNodeAddedChange_shell) ); }

jmethodID QPropertyNodeAddedChange_shell::__shell_javaMethod(int pos) const { return QPropertyNodeAddedChange_shell::__shell()->javaMethod(typeid(Qt3DCore::QPropertyNodeAddedChange), pos); }

// emitting (writeShellConstructor)
QPropertyNodeAddedChange_shell::QPropertyNodeAddedChange_shell(Qt3DCore::QNodeId subjectId0, Qt3DCore::QNode* node1)
    : Qt3DCore::QPropertyNodeAddedChange(subjectId0, node1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QPropertyNodeAddedChange::QPropertyNodeAddedChange_shell(Qt3DCore::QNodeId subjectId0, Qt3DCore::QNode* node1)", QPropertyNodeAddedChange_shell::__shell())
    QPropertyNodeAddedChange_shell::__shell()->constructed(typeid(Qt3DCore::QPropertyNodeAddedChange));
}

// emitting (writeShellDestructor)
QPropertyNodeAddedChange_shell::~QPropertyNodeAddedChange_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QPropertyNodeAddedChange::~Qt3DCore::QPropertyNodeAddedChange()", QPropertyNodeAddedChange_shell::__shell())
    QPropertyNodeAddedChange_shell::__shell()->destructed(typeid(Qt3DCore::QPropertyNodeAddedChange));
}

void QPropertyNodeAddedChange_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyNodeAddedChange_shell*>(ptr)->QPropertyNodeAddedChange_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QPropertyNodeAddedChange));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)
void __qt_construct_Qt3DCore_QPropertyNodeAddedChange_Qt3DCore_QNodeId_Qt3DCore_QNode_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    jobject node1 = __java_arguments[1].l;
    Qt3DCore::QNode* __qt_node1 = qtjambi_cast<Qt3DCore::QNode* >(__jni_env, node1);
    Qt3DCore::QPropertyNodeAddedChange *__qt_this = new(__qtjambi_ptr) QPropertyNodeAddedChange_shell(__qt_subjectId0, __qt_node1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QPropertyNodeAddedChange::QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyNodeAddedChange_initialize_1native__Lio_qt_qt3d_core_QPropertyNodeAddedChange_2Lio_qt_qt3d_core_QNodeId_2Lio_qt_qt3d_core_QNode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0,
 jobject node1)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QPropertyNodeAddedChange::QPropertyNodeAddedChange(Qt3DCore::QNodeId,Qt3DCore::QNode*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = subjectId0;
        arguments[1].l = node1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QPropertyNodeAddedChange_Qt3DCore_QNodeId_Qt3DCore_QNode_ptr, sizeof(QPropertyNodeAddedChange_shell), typeid(Qt3DCore::QPropertyNodeAddedChange), true, &deleter_Qt3DCore_QPropertyNodeAddedChange, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPropertyNodeAddedChange_shell
void __qt_destruct_Qt3DCore_QPropertyNodeAddedChange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QPropertyNodeAddedChange")
    reinterpret_cast<QPropertyNodeAddedChange_shell*>(ptr)->~QPropertyNodeAddedChange_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QPropertyNodeAddedChange::addedNodeId()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyNodeAddedChange_addedNodeId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QPropertyNodeAddedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QPropertyNodeAddedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QPropertyNodeAddedChange::addedNodeId()const", __qt_this)
        Qt3DCore::QNodeId __qt_return_value = __qt_this->addedNodeId();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QPropertyNodeAddedChange::metaObject()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyNodeAddedChange_metaObject_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QPropertyNodeAddedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QPropertyNodeAddedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QPropertyNodeAddedChange::metaObject()const", __qt_this)
        const QMetaObject* __qt_return_value = __qt_this->metaObject();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QPropertyNodeAddedChange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QPropertyNodeAddedChange>("Qt3DCore::QPropertyNodeAddedChange", "io/qt/qt3d/core/QPropertyNodeAddedChange");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QPropertyNodeAddedChange, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QPropertyNodeAddedChange_Qt3DCore_QNodeId_Qt3DCore_QNode_ptr, "Lio/qt/qt3d/core/QNodeId;Lio/qt/qt3d/core/QNode;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QPropertyNodeAddedChange);
    registerSizeOfShell(typeId, sizeof(QPropertyNodeAddedChange_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QStaticPropertyValueAddedChangeBase, Qt3DCore::QPropertyNodeAddedChange>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
